@@ -14,6 +14,7 @@ from ibm_cloud_sdk_core import CP4DTokenManager
 from ibm_cloud_sdk_core.authenticators import (IAMAuthenticator, NoAuthAuthenticator, Authenticator,
                                                BasicAuthenticator, CloudPakForDataAuthenticator)
 from ibm_cloud_sdk_core import get_authenticator_from_environment
+from ibm_cloud_sdk_core.utils import strip_extra_slashes
 
 
 class IncludeExternalConfigService(BaseService):
@@ -518,27 +519,37 @@ def test_json():
     req = service.prepare_request('POST', url='', headers={'X-opt-out': True}, data={'hello': 'world'})
     assert req.get('data') == "{\"hello\": \"world\"}"
 
-# For v2.x this test expects to see trailing slashes, this should be changed in v3.x
 def test_trailing_slash():
-    service = AnyServiceV1('2018-11-20', service_url='https://trailingSlash.com/', authenticator=NoAuthAuthenticator())
-    assert service.service_url == 'https://trailingSlash.com/'
-    service.set_service_url('https://trailingSlash.com/')
-    assert service.service_url == 'https://trailingSlash.com/'
+    assert strip_extra_slashes('') == ''
+    assert strip_extra_slashes('//') == '/'
+    assert strip_extra_slashes('/////') == '/'
+    assert strip_extra_slashes('https://host') == 'https://host'
+    assert strip_extra_slashes('https://host/') == 'https://host/'
+    assert strip_extra_slashes('https://host//') == 'https://host/'
+    assert strip_extra_slashes('https://host/path') == 'https://host/path'
+    assert strip_extra_slashes('https://host/path/') == 'https://host/path/'
+    assert strip_extra_slashes('https://host/path//') == 'https://host/path/'
+    assert strip_extra_slashes('https://host//path//') == 'https://host//path/'
+
+    service = AnyServiceV1('2018-11-20', service_url='https://host/', authenticator=NoAuthAuthenticator())
+    assert service.service_url == 'https://host/'
+    service.set_service_url('https://host/')
+    assert service.service_url == 'https://host/'
     req = service.prepare_request('POST',
-                                  url='/trailingSlashPath/',
+                                  url='/path/',
                                   headers={'X-opt-out': True},
                                   data={'hello': 'world'})
-    assert req.get('url') == 'https://trailingSlash.com//trailingSlashPath/'
+    assert req.get('url') == 'https://host//path/'
 
-    service = AnyServiceV1('2018-11-20', service_url='https://trailingSlash.com/', authenticator=NoAuthAuthenticator())
-    assert service.service_url == 'https://trailingSlash.com/'
-    service.set_service_url('https://trailingSlash.com/')
-    assert service.service_url == 'https://trailingSlash.com/'
+    service = AnyServiceV1('2018-11-20', service_url='https://host/', authenticator=NoAuthAuthenticator())
+    assert service.service_url == 'https://host/'
+    service.set_service_url('https://host/')
+    assert service.service_url == 'https://host/'
     req = service.prepare_request('POST',
                                   url='/',
                                   headers={'X-opt-out': True},
                                   data={'hello': 'world'})
-    assert req.get('url') == 'https://trailingSlash.com//'
+    assert req.get('url') == 'https://host/'
 
     service.set_service_url(None)
     assert service.service_url is None
@@ -551,7 +562,7 @@ def test_trailing_slash():
                                   url='/',
                                   headers={'X-opt-out': True},
                                   data={'hello': 'world'})
-    assert req.get('url') == '//'
+    assert req.get('url') == '/'
 
 def test_service_url_not_set():
     service = BaseService(service_url='', authenticator=NoAuthAuthenticator())
